@@ -1,13 +1,12 @@
 import logging
+import time
 
 from scrapy import signals
 from scrapy.exceptions import NotConfigured
-from .offset_monitor import check
 
 logger = logging.getLogger(__name__)
 
 
-# this example show a plan to close the spider
 class IdleClosedExensions(object):
 
     def __init__(self, idle_number, crawler):
@@ -37,6 +36,10 @@ class IdleClosedExensions(object):
                     spider.name, self.idle_count, len(self.idle_list))
 
     def spider_idle(self, spider):
-        res = check('sh kafka-consumer-groups.sh --bootstrap-server localhost:9092 --describe --group group_id')
-        if res == 'finished':
+        self.idle_count += 1
+        self.idle_list.append(time.time())
+        idle_list_len = len(self.idle_list)
+        if idle_list_len > 2 and self.idle_list[-1] - self.idle_list[-2] > 6:
+            self.idle_list = [self.idle_list[-1]]
+        elif idle_list_len > self.idle_number:
             self.crawler.engine.close_spider(spider, 'closespider_pagecount')
